@@ -1,6 +1,6 @@
 /*
  * Worldvisions Weaver Software:
- *   Copyright (C) 1997-2002 Net Integration Technologies, Inc.
+ *   Copyright (C) 1997-2003 Net Integration Technologies, Inc.
  *
  * Implementation of the WvDialer smart-dialer class.  
  *
@@ -19,7 +19,7 @@
 #include <ctype.h>
 #include <errno.h>
 #include <assert.h>
-
+#include <xplc/xplc.h>
 
 static char *	init_responses[] = {
 	"ok",
@@ -33,7 +33,6 @@ static char *	dial_responses[] = {
 	"no dialtone",
 	"no dial tone",
 	"busy",
-	"delayed",
 	"error",
 	"voice",
 	"fclass",
@@ -81,17 +80,17 @@ WvDialer::WvDialer( WvConf &_cfg, WvStringList *_sect_list, bool _chat_mode )
     sect_list = _sect_list;
     chat_mode = _chat_mode;
     
-    log( "WvDial: Internet dialer version " WVDIAL_VER_STRING "\n" );
+    log("WvDial: Internet dialer version " WVDIAL_VER_STRING "\n");
 
     // Ensure all sections in sect_list actually exist, warning if not.
-    WvStringList::Iter	iter( *sect_list );
-    for( iter.rewind(); iter.next(); ) 
+    WvStringList::Iter iter(*sect_list);
+    for(iter.rewind(); iter.next();) 
     {
-    	if( cfg[*iter] == NULL ) 
+    	if(cfg[*iter] == NULL) 
         {
-    	    err( WvLog::Warning,
-		 "Warning: section [%s] does not exist in wvdial.conf.\n",
-    	    	 *iter );
+    	    err(WvLog::Warning,
+		"Warning: section [%s] does not exist in wvdial.conf.\n",
+		*iter);
     	}
     }
  
@@ -112,40 +111,41 @@ WvDialer::WvDialer( WvConf &_cfg, WvStringList *_sect_list, bool _chat_mode )
     }  
  
     // Activate the brain and read configuration.
-    brain = new WvDialBrain( this );
+    brain = new WvDialBrain(this);
 
     // init_modem() reads the config options.  It MUST run here!
     
-    if( !init_modem() )
+    if(!init_modem())
     {
 	// init_modem() printed an error
 	stat = ModemError;
 	return;
     }
-
+    
     if (options.provider.len()) 
     {
 	log( WvLog::Notice, "Dialing %s %s.\n",
 		options.provider,
 		options.product);
     }
-    if (options.homepage.len()) {
-        log( WvLog::Notice, "Homepage of %s: %s\n",
-		options.provider.len() ? (const char *)options.provider : "this provider",
-		options.homepage);
+    if (options.homepage.len()) 
+    {
+        log(WvLog::Notice, "Homepage of %s: %s\n",
+	    options.provider.len() ? options.provider.cstr() : "this provider",
+	    options.homepage);
     }
 
-    if( options.auto_reconnect && options.idle_seconds > 0) 
+    if(options.auto_reconnect && options.idle_seconds > 0) 
     {
-    	err( WvLog::Notice,
+	err(WvLog::Notice,
 	    "Idle Seconds = %s, disabling automatic reconnect.\n",
-				WvString(options.idle_seconds));
+	    options.idle_seconds);
         options.auto_reconnect = false;
     }
     
-    pppd_mon.setdnstests (options.dnstest1, options.dnstest2);
-    pppd_mon.setcheckdns (options.check_dns);
-    pppd_mon.setcheckdfr (options.check_dfr);
+    pppd_mon.setdnstests(options.dnstest1, options.dnstest2);
+    pppd_mon.setcheckdns(options.check_dns);
+    pppd_mon.setcheckdfr(options.check_dfr);
 }
 
 WvDialer::~WvDialer()
@@ -153,41 +153,37 @@ WvDialer::~WvDialer()
 {
     terminate_continue_select();
 
-    if( ppp_pipe )
-	delete ppp_pipe;
-    if( pppd_log )
-        delete pppd_log;
-    if( brain )
-    	delete brain;
+    WVRELEASE(ppp_pipe);
+    WVRELEASE(pppd_log);
+    delete brain;
 }
 
 bool WvDialer::dial()
 /*******************/
 // Returns false on error, or true to go asynchronous while dialing.
 {
-    if( stat == Online )
-    	return( true );
+    if(stat == Online)
+    	return(true);
 	
-    if( stat != Idle ) 
+    if(stat != Idle) 
     {
-	// (error message has already been printed elsewhere)
-    	// err( "Modem is not ready to dial.\n" );
-    	return( false );
+	// error message has already been printed elsewhere
+    	return(false);
     }
 
-    if( !options.phnum[0] ) 
+    if (!options.phnum) 
     {
 	err( "Configuration does not specify a valid phone number.\n" );
     	stat = OtherError;
     }
 
-    if( !options.login[0] ) 
+    if (!options.login) 
     {
 	err( "Configuration does not specify a valid login name.\n" );
     	stat = OtherError;
     }
 
-    if( !options.password[0] ) 
+    if (!options.password) 
     {
 	err( "Configuration does not specify a valid password.\n" );
     	stat = OtherError;
@@ -197,25 +193,23 @@ bool WvDialer::dial()
 	return( false );
 
     phnum_max = 0;
-    if( options.phnum1.len() ) 
+    if(options.phnum1.len()) 
     { 
 	phnum_max++;
-        if( options.phnum2.len() ) 
+        if(options.phnum2.len()) 
 	{ 
 	    phnum_max++;
-            if( options.phnum3.len() ) 
+            if(options.phnum3.len()) 
 	    { 
 		phnum_max++;
-          	if( options.phnum4.len() ) 
-		{ 
+          	if(options.phnum4.len()) 
 		    phnum_max++;
-    		}
 	    }
 	}
     }
 
     // we need to re-init the modem if we were online before.
-    if( been_online && !init_modem() )
+    if(been_online && !init_modem())
 	stat = ModemError;
     else
     {
@@ -225,17 +219,13 @@ bool WvDialer::dial()
 	brain->reset();
     }
     
-    return( true );
+    return(true);
 }
 
 void WvDialer::hangup()
 /*********************/
 {
-    if( ppp_pipe ) 
-    {
-    	delete ppp_pipe;
-	ppp_pipe = NULL;
-    }
+    WVRELEASE(ppp_pipe);
     
     if( !chat_mode )
       pppd_watch( 250 );
@@ -286,7 +276,7 @@ bool WvDialer::isok() const
     return( b );
 }
 
-char * WvDialer::connect_status() const
+char *WvDialer::connect_status() const
 /*************************************/
 {
     static char msg[ 160 ];
@@ -339,10 +329,9 @@ void WvDialer::pppd_watch( int ms )
   
     if( pppd_log != NULL && pppd_log->isok() ) 
     {
-    
     	char *line;
     
-    	while ( (line = pppd_log->getline( ms )) )
+    	while ( (line = pppd_log->blocking_getline( ms )) )
     	{
 	    WvString buffer1(pppd_mon.analyse_line( line ));
 	    if (!!buffer1)
@@ -668,7 +657,7 @@ bool WvDialer::init_modem()
     
     load_options();
 
-    if( !options.modem[0] ) 
+    if (!options.modem) 
     {
 	err( "Configuration does not specify a valid modem device.\n" );
     	stat = ModemError;
@@ -801,8 +790,8 @@ void WvDialer::del_modem()
     if (modem)
     {
 	modem->hangup();
-	delete modem;
-	cloned = modem = NULL;
+	WVRELEASE(modem);
+	cloned = NULL;
     }
 }
 
@@ -1178,7 +1167,7 @@ void WvDialer::start_ppp()
     
     // open a pipe to pass password to pppd
     WvString buffer2;
-    if( options.password != NULL && options.password[0] != '\0' ) 
+    if (!options.password) 
     {
 	if( pipe( pppd_passwdfd ) == -1 ) 
 	{
@@ -1199,12 +1188,12 @@ void WvDialer::start_ppp()
 	"usehostname",
 	"-detach",
 	"user", options.login,
-	options.force_addr[0] ? (const char *)addr_colon : "noipdefault",
+	(!!options.force_addr) ? (const char *)addr_colon : "noipdefault",
 	options.new_pppd ? "call" : NULL, 
 	options.new_pppd ? "wvdial" : NULL,
 	options.new_pppd && options.auto_dns ? "usepeerdns"	   : NULL,
 	options.new_pppd && options.isdn     ? "default-asyncmap"  : NULL,
-	options.new_pppd && options.pppd_option[0] ? (const char *) options.pppd_option : NULL,
+	options.new_pppd && (!!options.pppd_option) ? (const char *) options.pppd_option : NULL,
 	options.new_pppd && options.idle_seconds >= 0 ? "idle"	   : NULL, 
 	options.new_pppd && options.idle_seconds >= 0 ? (const char *)idle_seconds : NULL, 
 	"logfd", buffer1,
@@ -1270,7 +1259,7 @@ void WvDialer::start_ppp()
     ppp_pipe = new WvPipe( argv[0], argv, false, false, false,
 			   modem, modem, modem );
 
-    log( WvLog::Notice, "pid of pppd: %s\n", ppp_pipe->getpid() );
+    log( WvLog::Notice, "Pid of pppd: %s\n", ppp_pipe->getpid() );
 
     stat 	 = Online;
     been_online  = true;
@@ -1365,7 +1354,7 @@ int WvDialer::wait_for_modem( char * 	strs[],
 	strlwr( buffer + onset );
 	
 	// Now we can search using strstr.
-	for( result = 0; strs[ result ] != NULL; result++ ) 
+	for( result = 0; strs[ result ] != NULL; result++ )
 	{
 	    len = strlen( strs[ result ] );
 	    soff = strstr( buffer, strs[ result ] );
